.. _api-managers:

Managers
========

.. automodule:: guardian.managers


.. manager:: UserObjectPermissionManager

UserObjectPermissionManager
---------------------------

.. autoclass:: guardian.managers.UserObjectPermissionManager
   :members:


.. manager:: GroupObjectPermissionManager

GroupObjectPermissionManager
----------------------------

.. autoclass:: guardian.managers.GroupObjectPermissionManager
   :members:
